Join a private chat or channel by invite link
Examples
if (FALSE) { # \dontrun{
client <- TelegramClient$new("my_session", api_id = 123, api_hash = "abc")
client$connect()
join_private_chat(client, "https://t.me/+xxxx")
} # }
Join a private chat or channel by invite link
if (FALSE) { # \dontrun{
client <- TelegramClient$new("my_session", api_id = 123, api_hash = "abc")
client$connect()
join_private_chat(client, "https://t.me/+xxxx")
} # }