Convenience wrapper to send an audio file to a target entity.
Examples
if (FALSE) { # \dontrun{
client <- TelegramClient$new("my_session", api_id = 123, api_hash = "abc")
client$connect()
send_audio(client, "me", "audio.mp3")
} # }
Convenience wrapper to send an audio file to a target entity.
if (FALSE) { # \dontrun{
client <- TelegramClient$new("my_session", api_id = 123, api_hash = "abc")
client$connect()
send_audio(client, "me", "audio.mp3")
} # }