Convenience wrapper to send a photo to a target entity.
Examples
if (FALSE) { # \dontrun{
client <- TelegramClient$new("my_session", api_id = 123, api_hash = "abc")
client$connect()
send_photo(client, "me", "photo.jpg")
} # }
Convenience wrapper to send a photo to a target entity.
if (FALSE) { # \dontrun{
client <- TelegramClient$new("my_session", api_id = 123, api_hash = "abc")
client$connect()
send_photo(client, "me", "photo.jpg")
} # }