Convenience wrapper to send a video to a target entity.
Examples
if (FALSE) { # \dontrun{
client <- TelegramClient$new("my_session", api_id = 123, api_hash = "abc")
client$connect()
send_video(client, "me", "video.mp4")
} # }
Convenience wrapper to send a video to a target entity.
if (FALSE) { # \dontrun{
client <- TelegramClient$new("my_session", api_id = 123, api_hash = "abc")
client$connect()
send_video(client, "me", "video.mp4")
} # }